@@ -2,7 +2,7 @@ import asyncio
 import logging
 from concurrent.futures import ThreadPoolExecutor
 from typing import Any, Awaitable, Callable
-from koil.helpers import iterate_spawned, run_spawned
+from koil.helpers import iterate_spawned, run_spawned, iterate_processed, run_processed
 from pydantic import BaseModel, Field
 from rekuest.actors.base import SerializingActor
 from rekuest.messages import Assignation, Provision
@@ -13,6 +13,7 @@ from rekuest.actors.types import OnProvide, OnUnprovide, Assignment, Unassignmen
 from rekuest.collection.collector import Collector
 from rekuest.actors.transport.types import AssignTransport
 from rekuest.structures.parse_collectables import parse_collectable
+from rekuest.structures.errors import SerializationError
 
 logger = logging.getLogger(__name__)
 
@@ -72,16 +73,22 @@ class AsyncFuncActor(SerializingActor):
                 returns=returns,
             )
 
+        except SerializationError as ex:
+            await transport.change_assignation(
+                status=AssignationStatus.CRITICAL,
+                message=str(ex),
+            )
+
         except AssertionError as ex:
             await transport.change_assignation(
-                status=AssignationStatus.ERROR,
+                status=AssignationStatus.CRITICAL,
                 message=str(ex),
             )
 
         except Exception as e:
             logger.error("Assignation error", exc_info=True)
             await transport.change_assignation(
-                status=AssignationStatus.CRITICAL,
+                status=AssignationStatus.ERROR,
                 message=repr(e),
             )
 
@@ -125,6 +132,12 @@ class AsyncGenActor(SerializingActor):
 
             await transport.change_assignation(status=AssignationStatus.DONE)
 
+        except SerializationError as ex:
+            await transport.change_assignation(
+                status=AssignationStatus.CRITICAL,
+                message=str(ex),
+            )
+
         except AssertionError as ex:
             await transport.change_assignation(
                 status=AssignationStatus.ERROR,
@@ -198,9 +211,15 @@ class ThreadedFuncActor(SerializingActor):
                 returns=returns,
             )
 
+        except SerializationError as ex:
+            await transport.change_assignation(
+                status=AssignationStatus.CRITICAL,
+                message=str(ex),
+            )
+
         except AssertionError as ex:
             await transport.change_assignation(
-                status=AssignationStatus.ERROR,
+                status=AssignationStatus.CRITICAL,
                 message=str(ex),
             )
 
@@ -256,7 +275,13 @@ class ThreadedGenActor(SerializingActor):
 
         except AssertionError as ex:
             await transport.change_assignation(
-                status=AssignationStatus.ERROR,
+                status=AssignationStatus.CRITICAL,
+                message=str(ex),
+            )
+
+        except SerializationError as ex:
+            await transport.change_assignation(
+                status=AssignationStatus.CRITICAL,
                 message=str(ex),
             )
 
@@ -270,6 +295,128 @@ class ThreadedGenActor(SerializingActor):
             raise e
 
 
+class ProcessedGenActor(SerializingActor):
+    async def on_assign(
+        self,
+        assignment: Assignation,
+        collector: Collector,
+        transport: AssignTransport,
+    ):
+        try:
+            params = await expand_inputs(
+                self.definition,
+                assignment.args,
+                structure_registry=self.structure_registry,
+                skip_expanding=not self.expand_inputs,
+            )
+            await transport.change_assignation(
+                status=AssignationStatus.ASSIGNED,
+            )
+
+            async with AssignationContext(assignment=assignment, transport=transport):
+                async for returns in iterate_processed(self.assign, **params):
+                    returns = await shrink_outputs(
+                        self.definition,
+                        returns,
+                        structure_registry=self.structure_registry,
+                        skip_shrinking=not self.shrink_outputs,
+                    )
+
+                    collector.register(
+                        assignment, parse_collectable(self.definition, returns)
+                    )
+
+                    await self.transport.change_assignation(
+                        status=AssignationStatus.YIELD,
+                        returns=returns,
+                    )
+
+            await transport.change_assignation(status=AssignationStatus.DONE)
+
+        except AssertionError as ex:
+            await transport.change_assignation(
+                status=AssignationStatus.CRITICAL,
+                message=str(ex),
+            )
+
+        except SerializationError as ex:
+            await transport.change_assignation(
+                status=AssignationStatus.CRITICAL,
+                message=str(ex),
+            )
+
+        except Exception as e:
+            logging.critical(f"Assignation Error {assignment} {e}", exc_info=True)
+            await transport.change_assignation(
+                status=AssignationStatus.CRITICAL,
+                message=str(e),
+            )
+
+            raise e
+
+
+class ProcessedFuncActor(SerializingActor):
+    async def on_assign(
+        self,
+        assignment: Assignment,
+        collector: Collector,
+        transport: AssignTransport,
+    ):
+        try:
+            logger.info("Assigning Number two")
+            params = await expand_inputs(
+                self.definition,
+                assignment.args,
+                structure_registry=self.structure_registry,
+                skip_expanding=not self.expand_inputs,
+            )
+
+            await transport.change_assignation(
+                status=AssignationStatus.ASSIGNED,
+            )
+
+            print("Assigning processed")
+
+            async with AssignationContext(assignment=assignment, transport=transport):
+                returns = await run_processed(
+                    self.assign,
+                    **params,
+                )
+
+            returns = await shrink_outputs(
+                self.definition,
+                returns,
+                structure_registry=self.structure_registry,
+                skip_shrinking=not self.shrink_outputs,
+            )
+
+            collector.register(assignment, parse_collectable(self.definition, returns))
+
+            await transport.change_assignation(
+                status=AssignationStatus.RETURNED,
+                returns=returns,
+            )
+
+        except SerializationError as ex:
+            await transport.change_assignation(
+                status=AssignationStatus.CRITICAL,
+                message=str(ex),
+            )
+
+        except AssertionError as ex:
+            await transport.change_assignation(
+                status=AssignationStatus.CRITICAL,
+                message=str(ex),
+            )
+
+        except Exception as e:
+            logger.error("Error in actor", exc_info=True)
+            await transport.change_assignation(
+                status=AssignationStatus.CRITICAL,
+                message=str(e),
+            )
+
+
 class FunctionalThreadedFuncActor(FunctionalActor, ThreadedFuncActor):
     async def progress(self, value, percentage):
         await self._progress(value, percentage)
@@ -284,3 +431,19 @@ class FunctionalThreadedGenActor(FunctionalActor, ThreadedGenActor):
 
     class Config:
         arbitrary_types_allowed = True
+
+
+class FunctionalProcessedFuncActor(FunctionalActor, ProcessedFuncActor):
+    async def progress(self, value, percentage):
+        await self._progress(value, percentage)
+
+    class Config:
+        arbitrary_types_allowed = True
+
+
+class FunctionalProcessedGenActor(FunctionalActor, ProcessedGenActor):
+    async def progress(self, value, percentage):
+        await self._progress(value, percentage)
+
+    class Config:
+        arbitrary_types_allowed = True
